
function Meas_mtx =gen_data_nonoise(original_network,B_vct,time_points,plot_data)

% This function generates the state response, taking a certain number of
% points (time_points), of a stable dynamical linear system
% (dot(x)= Ax +Bu), whose A (dynamic matrix) is original_network and
% the B vector is B_vec.
%
% INPUT VARIABLES
%
% original_network:  the dynamic matrix of the stable dynamic linear system
%
% B_vct:             the vector that models the effect of external
%                    perturbations
% 
% time_points:       number of time points of the state response 
%
% plot_data:         if true, plot the data
%
% OUTPUT VARIABLES
%   
% Meas_mtx          Measurements matrix without noise, each column contains 
%                   the measurements for a node


% number of nodes of the network
n_nodes=size(original_network,1);

% generate the stable linear system
sys=ss(original_network,B_vct,zeros(1,n_nodes),0);

% calculate the eigenvalues (eig_values), the settling time (time_F) and   
% times vector (time) with a fixed sampling time (sample_int)
eig_val=eig(original_network);
tau=1/max(real(eig_val));
time_F=3*abs(tau);
sample_int=time_F/(time_points-1);
time=0:sample_int:time_F;

% initial condition of each state variable is chosen as a random value, 
% with a uniform distribution in [-1, 1]
x0=-1 +2.*rand(n_nodes,1);

% define a vector that models the external perturbation
U=ones(1,length(time));

% Sample the state response
[Y,T,Meas_mtx] = lsim(sys,U,time,x0);


if plot_data
    figure
    plot(Meas_mtx)
end