
function Cnct_Mtx=net_mask(n_nodes,nod_count,n_link,prob_p,prob_q)

% Representation of a graph (that can describe a biological interaction 
% network) by its adjacency matrix, generated by using the scalefree 
% network generation model proposed by Albert and Barabasi.
%
% INPUT VARIABLES
%
% n_nodes:     number of nodes of the graph
%
% nod_count:   number of isolated nodes at the initial time
%
% n_link:      number of the new links that we add at each time point 
%
% prob_p:      value of the probability through which we add new link 
%
% prob_q:      value of the probability through which we rewire some link
%              (n_link)
%
% OUTPUT VARIABLES
%
% Cnct_Mtx:    adjacency matrix with n_nodes*n_nodes elements


Cnct_Mtx=zeros(n_nodes,n_nodes);
max_num_it_wire=n_nodes;
max_num_it_rewire=n_nodes;
max_num_it_added=n_nodes;
%with probability 1-p-q we add a new node
% prob_1_pq=1-prob_p-prob_q;


while nod_count < n_nodes
    val_prob=rand(1,1);
    if val_prob<=prob_p % if the condition is true we add new links (n_link)
        n_link_wire=0;
        num_it_wire=0;
        % repeat m times 
        while n_link_wire<n_link && num_it_wire<=max_num_it_wire
            num_it_wire=num_it_wire+1; 
            % we randomly select a node as the starting point of the new link
             vct_start_point=randperm(nod_count);
             % node as the starting point of the new link
             nod_start_point=vct_start_point(1);
             vct_pr_end_point=zeros(1,nod_count);
             % the other end of the link is selected with probability 
             %            ki+1
             % P(ki)=-------------
             %         Sum_j(kj+1)        
             for idx2=1:nod_count
                 vct_pr_end_point(idx2)=(1+nnz(Cnct_Mtx(idx2,1:nod_count)))/...
                        (nod_count+nnz(Cnct_Mtx(1:nod_count,1:nod_count)));
             end
             rand_v=rand(1,1);
             if rand_v<=vct_pr_end_point(1)
                nod_end_point=1;
             else
                 for idx2=2:nod_count
                     if (sum(vct_pr_end_point(1:idx2-1))< rand_v && rand_v <= sum(vct_pr_end_point(1:idx2)))
                         nod_end_point=idx2;
                     end
                 end
             end
             if nod_end_point~=nod_start_point && Cnct_Mtx(nod_end_point,nod_start_point)==0
                 Cnct_Mtx(nod_end_point,nod_start_point)=1;
                 n_link_wire=n_link_wire+1;
             end
             clear nod_end_point nod_start_point
        end
         
    elseif val_prob>prob_p && val_prob<=prob_q+prob_p % if the condition is true we rewire some links (n_link)
        if nnz(Cnct_Mtx(1:nod_count,1:nod_count))>n_link
            n_link_rewire=0;%links counter
            num_it_rewire=0;
            while n_link_rewire < n_link && num_it_rewire<max_num_it_rewire
                num_it_rewire=num_it_rewire+1;
                % we randomly select a node i and a link lij connected to
                % it
                vct_start_point=randperm(nod_count);
                nod_start_point=vct_start_point(1);
                idx_nod_end_point=find(Cnct_Mtx(1:nod_count,nod_start_point));
                rand_idx_nod_end_point=idx_nod_end_point(randperm(length(idx_nod_end_point)));
                if ~isempty(rand_idx_nod_end_point)
                    nod_end_point=rand_idx_nod_end_point(1);
                    % remove the randomly selected link 
                    Cnct_Mtx(nod_end_point,nod_start_point)=0;
                    vct_pr_end_point=zeros(1,nod_count);
                    % replace the removed link with a new link that
                    % connects i(nod_start_point)with the node chosen with 
                    % probability 
                    %            ki+1
                    % P(ki)=-------------
                    %         Sum_j(kj+1)
                    for idx2=1:nod_count
                            vct_pr_end_point(idx2)=(1+nnz(Cnct_Mtx(idx2,1:nod_count)))/...
                                (nod_count+nnz(Cnct_Mtx(1:nod_count,1:nod_count)));
                    end
                    
                    rand_v=rand(1,1);
                    if rand_v<=vct_pr_end_point(1)
                        nod_end_point=1;
                    else
                        for idx2=2:nod_count
                            if (sum(vct_pr_end_point(1:idx2-1))< rand_v && rand_v <= sum(vct_pr_end_point(1:idx2)))
                                nod_end_point=idx2;
                            end
                        end
                    end
                    if nod_end_point~=nod_start_point && Cnct_Mtx(nod_end_point,nod_start_point)==0
                        Cnct_Mtx(nod_end_point,nod_start_point)=1; % the riwered link
                        n_link_rewire=1+n_link_rewire; %increment the links counter
                    end
                    clear nod_end_point
                end
                clear nod_start_point rand_idx_nod_end_point 
            end
        end  
    else
        % we add a new node 
        nod_count=nod_count+1;
        % the new node has some links (n_link)
        n_link_added=0;
        num_it_added=0;
        while n_link_added<n_link && num_it_added<=max_num_it_added
            num_it_added=num_it_added+1;
            nod_start_point=nod_count;
             vct_pr_end_point=zeros(1,nod_count);
             % we select the ending point of the link with probability
             %            ki+1
             % P(ki)=-------------
             %         Sum_j(kj+1)
             for idx2=1:nod_count
                    vct_pr_end_point(idx2)=(1+nnz(Cnct_Mtx(idx2,1:nod_count)))/...
                        (nod_count+nnz(Cnct_Mtx(1:nod_count,1:nod_count)));
             end
             rand_v=rand(1,1);
             if rand_v<=vct_pr_end_point(1)
                nod_end_point=1;
             else
                 for idx2=2:nod_count
                     if (sum(vct_pr_end_point(1:idx2-1))< rand_v && rand_v <= sum(vct_pr_end_point(1:idx2)))
                         nod_end_point=idx2;
                     end
                 end
             end
             if nod_end_point~=nod_start_point && Cnct_Mtx(nod_end_point,nod_start_point)==0
                 Cnct_Mtx(nod_end_point,nod_start_point)=1;
                 n_link_added=n_link_added+1;
             end
             clear nod_end_point 
        end
        clear nod_start_point
    end
end
for idx=1:n_nodes
    Cnct_Mtx(idx,idx)=1;
end


