
function Constr_mtx= sel_constr(original_network,pk)
% The function generate a list of constraints to be imposed on the matrix
% coefficients
%
% INPUT VARIABLES 
%
% original_network: the dynamic matrix of the stable dynamic linear system
%
% pk:               fraction of prior knowledge to be imposed 
%
% OUTPUT VARIABLE
%
% Constr_mtx: Matrix with 3 columns.
%             Constraints to be imposed on the matrix coefficients
%             first column --> row-index of the constrained coefficient
%             second column --> column-index of the constrained coefficient
%             third column --> sign of the constrained coefficient


if pk>0 
    [n_row,n_col]=size(original_network);
    n_nodes=n_row;
    Mtx_sign_stb=zeros(n_nodes,n_nodes);
    for idx1=1:n_row
        for idx2=[1:idx1-1,idx1+1:n_col]
            if original_network(idx1,idx2)
                Mtx_sign_stb(idx1,idx2) = sign(original_network(idx1,idx2));
            end
        end
    end

    [idx_row,idx_col,sign_val] = find(Mtx_sign_stb);
    num_vincoli_pk=ceil(length(idx_row)*pk);

    idx_row_pk=zeros(num_vincoli_pk,1);
    idx_col_pk=zeros(num_vincoli_pk,1);
    sign_val_pk=zeros(num_vincoli_pk,1);

    idx_rand=randperm(length(idx_row));

    for idx1=1:num_vincoli_pk
        idx_row_pk(idx1)=idx_row(idx_rand(idx1));
        idx_col_pk(idx1)=idx_col(idx_rand(idx1));
        sign_val_pk(idx1)=sign_val(idx_rand(idx1));
    end


    Constr_mtx=[idx_row_pk,idx_col_pk,sign_val_pk];
else
    Constr_mtx=[];
end

