% This script enables to compute the N_kin and N_kout averaged over a set  
% of twenty (n_nets) in silico networks, each of twenty nodes (n_nodes)

% number of networks
n_nets=20;
% number of nodes
n_nodes=20;

% define matrices to store the k_in and k_out  
mtx_kin=zeros(n_nets,n_nodes-1);
mtx_kout=zeros(n_nets,n_nodes-1);
% define a vector to store the sparsity of each network
spar_coef_vct=zeros(1,n_nets);

for n_net=1:n_nets
    % load the data for the current network
    eval(['load data_net_in_silico_20n\sys_in_silico_20n_net_',...
        num2str(n_net)]);
    spar_coef_vct(n_net)=spar_coef;
    % number of columns of the connectivity matrix
    num_col=size(original_network,2);
    
    % number of non zero elements for each column, don't consider the
    % elements on the diagonal
    n_link_col=zeros(1,num_col);
    for idx=1:num_col
        n_link_col(idx)=nnz(original_network(:,idx))-1;
    end
    
    % max number of non zero elements
    k_max=num_col-1;
    % determine the N(k_out), the number of nodes with the same k_out 
    num_count=zeros(1,k_max);
    for idx1=1:k_max
        count=0;
        for idx2=1:num_col
            if n_link_col(idx2)==idx1
                count=count+1;
            end
        end
        num_count(idx1)=count;
    end
    % store the N(k_out) for the current network 
    mtx_kout(n_net,:)=num_count;
    clear num_count
    
    % number of rows of the connectivity matrix
    % num_row=num_col;
    num_row=size(original_network,1);
    
    % number of non zero elements for each row, don't consider the
    % elements on the diagonal
    n_link_row=zeros(1,num_row);
    for idx=1:num_row
        n_link_row(idx)=nnz(original_network(idx,:))-1;
    end

    % max number of non zero elements
    k_max=num_row-1;
    
    % determine the N(k_in), the number of nodes with the same k_in
    num_count=zeros(1,k_max);
    for idx1=1:k_max
        count=0;
        for idx2=1:num_row
            if n_link_row(idx2)==idx1
                count=count+1;
            end
        end
        num_count(idx1)=count;
    end
    
    % store the N(k_in) for the current network
    mtx_kin(n_net,:)=num_count;
    clear num_count
end


% compute average in degree
average_kin_net=zeros(1,20);
for idx_net=1:20;
    kin_net=mtx_kin(idx_net,:);
    idx_nnz=find(kin_net);
    kin_net([1 idx_nnz(end)+1:end])=NaN;
    average_kin_net(idx_net)=nanmean(kin_net);
end
average_kin=mean(average_kin_net);

% compute and plot the average N(k_in) and N(k_out)
mean_kin=mean(mtx_kin);
mean_kout=mean(mtx_kout);
figure
hold on;
grid on
s1=subplot(2,1,1);
bar(mean_kin)
set(s1,'FontSize',12)
ylabel('N(k_{in})','FontSize',12);
xlabel('k_{in}','FontSize',12)
ylim([0 6])
xlim([0 19])
s2=subplot(2,1,2)
bar(mean_kout)
ylim([0 6])
xlim([0 19])
set(s2,'FontSize',12)
ylabel('N(k_{out})','FontSize',12);
xlabel('k_{out}','FontSize',12)